@@ -1,4 +1,6 @@
+# -*- coding: utf-8 -*-
 # Feed this with git rev-list HEAD --parents
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import sys
 
@@ -9,7 +11,7 @@ for line in sys.stdin.readlines():
 
 sequence_num = {}
 stack = []
-for commit in parents.keys():
+for commit in parents:
     stack.append(commit)
     while stack:
         c = stack.pop()
@@ -26,6 +28,5 @@ for commit in parents.keys():
         else:
             sequence_num[c] = 0
 
-(num, commit) = max((num, commit) for (commit, num)
-                    in sequence_num.iteritems())
-print '%s is a sequence of %d patches' % (commit, num)
+(num, commit) = max((num, commit) for (commit, num) in sequence_num.items())
+print('%s is a sequence of %d patches' % (commit, num))
