@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import os
 
-from stgit import argparse
-from stgit.commands import common
-from stgit.lib import git, stack
+from stgit.commands.common import (
+    CmdException,
+    DirectoryAnywhere,
+    DirectoryHasRepository,
+)
+from stgit.lib.git import clone
+from stgit.lib.stack import Stack
 
 __copyright__ = """
 Copyright (C) 2009, Catalin Marinas <catalin.marinas@gmail.com>
@@ -38,10 +42,11 @@ commands of linkstg:branch[].
 The target directory <dir> will be created by this command, and must
 not already exist."""
 
-args = [argparse.repo, argparse.dir]
+args = ['repo', 'dir']
 options = []
 
-directory = common.DirectoryAnywhere(needs_current_series = False, log = False)
+directory = DirectoryAnywhere()
+
 
 def func(parser, options, args):
     """Clone the <repository> into the local <dir> and initialises the
@@ -54,10 +59,10 @@ def func(parser, options, args):
     local_dir = args[1]
 
     if os.path.exists(local_dir):
-        raise common.CmdException('"%s" exists. Remove it first' % local_dir)
+        raise CmdException('"%s" exists. Remove it first' % local_dir)
 
-    git.clone(repository, local_dir)
+    clone(repository, local_dir)
     os.chdir(local_dir)
-    directory = common.DirectoryHasRepositoryLib()
+    directory = DirectoryHasRepository()
     directory.setup()
-    stack.Stack.initialise(directory.repository)
+    Stack.initialise(directory.repository)
