@@ -1,3 +1,11 @@
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+from stgit.argparse import opt, patch_range
+from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
+from stgit.lib import transaction
+from stgit.out import out
+
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
 
@@ -14,18 +22,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
-from stgit.argparse import opt
-from stgit.commands import common
-from stgit.lib import transaction
-from stgit.out import *
-from stgit import argparse
-
 help = 'Permanently store the applied patches into the stack base'
 kind = 'stack'
-usage = ['',
-         '[--] <patchnames>',
-         '-n NUM',
-         '--all']
+usage = ['', '[--] <patchnames>', '-n NUM', '--all']
 description = """
 Merge one or more patches into the base of the current stack and
 remove them from the series while advancing the base. This is the
@@ -40,57 +39,64 @@ The -n/--number option specifies the number of applied patches to
 commit (counting from the bottom of the stack). If -a/--all is given,
 all applied patches are committed."""
 
-args = [argparse.patch_range(argparse.applied_patches,
-                             argparse.unapplied_patches)]
+args = [patch_range('applied_patches', 'unapplied_patches')]
 options = [
-    opt('-n', '--number', type = 'int',
-        short = 'Commit the specified number of patches'),
-    opt('-a', '--all', action = 'store_true',
-        short = 'Commit all applied patches')]
+    opt('-n', '--number', type='int', short='Commit the specified number of patches',),
+    opt('-a', '--all', action='store_true', short='Commit all applied patches'),
+]
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Commit a number of patches."""
     stack = directory.repository.current_stack
-    args = common.parse_patches(args, list(stack.patchorder.all_visible))
-    if len([x for x in [args, options.number != None, options.all] if x]) > 1:
+    args = parse_patches(args, list(stack.patchorder.all_visible))
+    exclusive = [args, options.number is not None, options.all]
+    if sum(map(bool, exclusive)) > 1:
         parser.error('too many options')
     if args:
         patches = [pn for pn in stack.patchorder.all_visible if pn in args]
         bad = set(args) - set(patches)
         if bad:
-            raise common.CmdException('Nonexistent or hidden patch names: %s'
-                                      % ', '.join(sorted(bad)))
-    elif options.number != None:
+            raise CmdException(
+                'Nonexistent or hidden patch names: %s' % (', '.join(sorted(bad)),)
+            )
+    elif options.number is not None:
         if options.number <= len(stack.patchorder.applied):
-            patches = stack.patchorder.applied[:options.number]
+            patches = stack.patchorder.applied[: options.number]
         else:
-            raise common.CmdException('There are not that many applied patches')
+            raise CmdException('There are not that many applied patches')
     elif options.all:
         patches = stack.patchorder.applied
     else:
         patches = stack.patchorder.applied[:1]
     if not patches:
-        raise common.CmdException('No patches to commit')
+        raise CmdException('No patches to commit')
 
     iw = stack.repository.default_iw
+
     def allow_conflicts(trans):
         # As long as the topmost patch stays where it is, it's OK to
         # run "stg commit" with conflicts in the index.
         return len(trans.applied) >= 1
-    trans = transaction.StackTransaction(stack, 'commit',
-                                         allow_conflicts = allow_conflicts)
+
+    trans = transaction.StackTransaction(
+        stack, 'commit', allow_conflicts=allow_conflicts
+    )
     try:
         common_prefix = 0
-        for i in xrange(min(len(stack.patchorder.applied), len(patches))):
+        for i in range(min(len(stack.patchorder.applied), len(patches))):
             if stack.patchorder.applied[i] == patches[i]:
                 common_prefix += 1
             else:
                 break
         if common_prefix < len(patches):
-            to_push = [pn for pn in stack.patchorder.applied[common_prefix:]
-                       if pn not in patches[common_prefix:]]
+            to_push = [
+                pn
+                for pn in stack.patchorder.applied[common_prefix:]
+                if pn not in patches[common_prefix:]
+            ]
             # this pops all the applied patches from common_prefix
             trans.pop_patches(lambda pn: pn in to_push)
             for pn in patches[common_prefix:]:
@@ -102,8 +108,7 @@ def func(parser, options, args):
             trans.patches[pn] = None
         trans.applied = [pn for pn in trans.applied if pn not in patches]
         trans.base = new_base
-        out.info('Committed %d patch%s' % (len(patches),
-                                           ['es', ''][len(patches) == 1]))
+        out.info('Committed %d patch%s' % (len(patches), ['es', ''][len(patches) == 1]))
         for pn in to_push:
             trans.push_patch(pn, iw)
     except transaction.TransactionHalted:
