@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import io
 import re
 import sys
 
-from stgit import argparse
-from stgit.argparse import opt
-from stgit.commands import common
+from stgit.argparse import keep_option, opt, patch_range
+from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
 from stgit.lib import transaction
 
 __copyright__ = """
@@ -29,22 +28,26 @@ along with this program; if not, see http://www.gnu.org/licenses/.
 
 help = 'Push patches to the top, even if applied'
 kind = 'stack'
-usage = ['[--] <patches>',
-         '-s <series>']
+usage = ['[--] <patches>', '-s <series>']
 description = """
-Push a patch or a range of patches to the top even if applied. The
-necessary pop and push operations will be performed to accomplish
-this. The '--series' option can be used to rearrange the (top) patches
-as specified by the given series file (or the standard input)."""
+Float a patch or range of patches to be the top-most applied patches.
+The patches to be floated may currently be either applied or unapplied.
+The necessary pop and push operations will be performed to float the
+named patches.  Patches not specified will remain applied or unapplied
+as they were prior to the float operation."""
 
-args = [argparse.patch_range(argparse.applied_patches,
-                             argparse.unapplied_patches)]
+args = [patch_range('applied_patches', 'unapplied_patches')]
 options = [
-    opt('-s', '--series', metavar = 'FILE',
-        short = 'Rearrange according to the series FILE')
-    ] + argparse.keep_option()
+    opt(
+        '-s',
+        '--series',
+        metavar='FILE',
+        short='Rearrange according to the series FILE',
+    )
+] + keep_option()
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Reorder patches to make the named patch the topmost one.
@@ -68,22 +71,20 @@ def func(parser, options, args):
             if patch:
                 patches.append(patch)
     else:
-        patches = common.parse_patches(args, stack.patchorder.all)
+        patches = parse_patches(args, stack.patchorder.all)
 
     if not patches:
-        raise common.CmdException('No patches to float')
+        raise CmdException('No patches to float')
 
-    applied = [p for p in stack.patchorder.applied if p not in patches] + \
-            patches
+    applied = [p for p in stack.patchorder.applied if p not in patches] + patches
     unapplied = [p for p in stack.patchorder.unapplied if p not in patches]
 
     iw = stack.repository.default_iw
     clean_iw = (not options.keep and iw) or None
-    trans = transaction.StackTransaction(stack, 'float',
-                                         check_clean_iw = clean_iw)
+    trans = transaction.StackTransaction(stack, 'float', check_clean_iw=clean_iw)
 
     try:
-        trans.reorder_patches(applied, unapplied, iw = iw)
+        trans.reorder_patches(applied, unapplied, iw=iw)
     except transaction.TransactionHalted:
         pass
     return trans.run(iw)
