@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from stgit import argparse
-from stgit.commands import common
+from stgit.commands.common import (
+    CmdException,
+    DirectoryHasRepository,
+    get_patch_from_list,
+)
 from stgit.lib import transaction
 
 __copyright__ = """
@@ -29,10 +32,11 @@ description = """
 Push/pop patches to/from the stack until the one given on the command
 line becomes current."""
 
-args = [argparse.other_applied_patches, argparse.unapplied_patches]
+args = ['other_applied_patches', 'unapplied_patches']
 options = argparse.keep_option() + argparse.merged_option()
 
-directory = common.DirectoryHasRepositoryLib()
+directory = DirectoryHasRepository()
+
 
 def func(parser, options, args):
     if len(args) != 1:
@@ -42,30 +46,31 @@ def func(parser, options, args):
     stack = directory.repository.current_stack
     iw = stack.repository.default_iw
     clean_iw = (not options.keep and iw) or None
-    trans = transaction.StackTransaction(stack, 'goto',
-                                         check_clean_iw = clean_iw)
+    trans = transaction.StackTransaction(stack, 'goto', check_clean_iw=clean_iw)
 
     if patch not in trans.all_patches:
-        candidate = common.get_patch_from_list(patch, trans.all_patches)
+        candidate = get_patch_from_list(patch, trans.all_patches)
         if candidate is None:
-            raise common.CmdException('Patch "%s" does not exist' % patch)
+            raise CmdException('Patch "%s" does not exist' % patch)
         patch = candidate
 
     if patch in trans.applied:
-        to_pop = set(trans.applied[trans.applied.index(patch)+1:])
-        assert not trans.pop_patches(lambda pn: pn in to_pop)
+        to_pop = set(trans.applied[trans.applied.index(patch) + 1 :])
+        popped_extra = trans.pop_patches(lambda pn: pn in to_pop)
+        assert not popped_extra
     elif patch in trans.unapplied:
         try:
-            to_push = trans.unapplied[:trans.unapplied.index(patch)+1]
+            to_push = trans.unapplied[: trans.unapplied.index(patch) + 1]
             if options.merged:
                 merged = set(trans.check_merged(to_push))
             else:
                 merged = set()
             for pn in to_push:
-                trans.push_patch(pn, iw, allow_interactive = True,
-                                 already_merged = pn in merged)
+                trans.push_patch(
+                    pn, iw, allow_interactive=True, already_merged=pn in merged
+                )
         except transaction.TransactionHalted:
             pass
     else:
-        raise common.CmdException('Cannot goto a hidden patch')
+        raise CmdException('Cannot goto a hidden patch')
     return trans.run(iw)
