@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse
-from stgit.commands import common
+from stgit.argparse import opt, patch_range
+from stgit.commands.common import DirectoryHasRepository, parse_patches
 from stgit.lib import transaction
 from stgit.out import out
 
@@ -30,13 +29,18 @@ description = """
 Hide a range of unapplied patches so that they are no longer shown in
 the plain 'series' command output."""
 
-args = [argparse.patch_range(argparse.applied_patches,
-                             argparse.unapplied_patches)]
+args = [patch_range('applied_patches', 'unapplied_patches')]
 options = [
-    argparse.opt('-b', '--branch', args=[argparse.stg_branches],
-                 short='Use BRANCH instead of the default branch')]
+    opt(
+        '-b',
+        '--branch',
+        args=['stg_branches'],
+        short='Use BRANCH instead of the default branch',
+    )
+]
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Hide a range of patch in the series."""
@@ -46,7 +50,7 @@ def func(parser, options, args):
     if not args:
         parser.error('No patches specified')
 
-    patches = common.parse_patches(args, trans.all_patches)
+    patches = parse_patches(args, trans.all_patches)
     for p in patches:
         if p in trans.hidden:
             out.warn('Patch "%s" already hidden' % p)
