@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse
-from stgit.commands import common
+from stgit.commands.common import DirectoryHasRepository, git_commit
 from stgit.out import out
 
 __copyright__ = """
@@ -34,11 +32,11 @@ to the stack (see the 'publish' command for details). If no branch is
 specified, it defaults to the current one. The bottom of a patch is accessible
 with the '[<branch>:]<patch>^' format."""
 
-args = [argparse.applied_patches, argparse.unapplied_patches,
-        argparse.hidden_patches]
+args = ['applied_patches', 'unapplied_patches', 'hidden_patches']
 options = []
 
-directory = common.DirectoryHasRepositoryLib()
+directory = DirectoryHasRepository()
+
 
 def func(parser, options, args):
     """Show the applied patches
@@ -50,4 +48,4 @@ def func(parser, options, args):
     else:
         parser.error('incorrect number of arguments')
 
-    out.stdout(common.git_commit(id_str, directory.repository).sha1)
+    out.stdout(git_commit(id_str, directory.repository).sha1)
