@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit.commands import common
-from stgit.lib import stack
+from stgit.commands.common import DirectoryHasRepository
+from stgit.lib.stack import Stack
 
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
@@ -32,7 +31,8 @@ contain at least one commit."""
 args = []
 options = []
 
-directory = common.DirectoryHasRepositoryLib()
+directory = DirectoryHasRepository()
+
 
 def func(parser, options, args):
     """Performs the repository initialisation
@@ -40,4 +40,4 @@ def func(parser, options, args):
     if len(args) != 0:
         parser.error('incorrect number of arguments')
 
-    stack.Stack.initialise(directory.repository)
+    Stack.initialise(directory.repository)
