@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse
 from stgit.argparse import opt
-from stgit.commands import common
+from stgit.commands.common import CmdException, DirectoryHasRepository
 from stgit.out import out
 
 __copyright__ = """
@@ -31,10 +29,16 @@ Print the name of the next patch."""
 
 args = []
 options = [
-    opt('-b', '--branch', args = [argparse.stg_branches],
-        short = 'Use BRANCH instead of the default branch')]
+    opt(
+        '-b',
+        '--branch',
+        args=['stg_branches'],
+        short='Use BRANCH instead of the default branch',
+    )
+]
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Show the name of the next patch
@@ -48,4 +52,4 @@ def func(parser, options, args):
     if unapplied:
         out.stdout(unapplied[0])
     else:
-        raise common.CmdException('No unapplied patches')
+        raise CmdException('No unapplied patches')
