@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from stgit import argparse, utils
 from stgit.argparse import opt
-from stgit.commands import common
-from stgit.lib import git, transaction
+from stgit.commands.common import (
+    CmdException,
+    DirectoryHasRepository,
+    get_public_ref,
+    update_commit_data,
+)
+from stgit.lib.git import CommitData, Person
+from stgit.lib.transaction import StackTransaction
 from stgit.out import out
 
 __copyright__ = """
@@ -24,10 +29,13 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
-help = 'Push the stack changes to a merge-friendly branch'
+help = '(DEPRECATED) Push the stack changes to a merge-friendly branch'
 kind = 'stack'
 usage = ['[options] [--] [branch]']
 description = """
+DEPRECATED: The 'stg publish' command will be removed in a future version of
+StGit.
+
 This command commits a set of changes on a separate (called public) branch
 based on the modifications of the given or current stack. The history of the
 public branch is not re-written, making it merge-friendly and feasible for
@@ -66,53 +74,79 @@ The public branch name can be set via the branch.<branch>.public configuration
 variable (defaulting to "<branch>.public").
 """
 
-args = [argparse.all_branches]
+args = ['all_branches']
 options = [
-    opt('-b', '--branch', args = [argparse.stg_branches],
-        short = 'Use BRANCH instead of the default branch'),
-    opt('-l', '--last', action = 'store_true',
-        short = 'Show the last published patch'),
-    opt('-u', '--unpublished', action = 'store_true',
-        short = 'Show applied patches that have not been published')
-] + (argparse.author_options()
-     + argparse.message_options(save_template = False)
-     + argparse.sign_options())
+    opt(
+        '-b',
+        '--branch',
+        args=['stg_branches'],
+        short='Use BRANCH instead of the default branch',
+    ),
+    opt('-l', '--last', action='store_true', short='Show the last published patch',),
+    opt(
+        '-u',
+        '--unpublished',
+        action='store_true',
+        short='Show applied patches that have not been published',
+    ),
+    opt(
+        '--overwrite',
+        action='store_true',
+        short='Overwrite branch instead of creating new commits',
+    ),
+] + (
+    argparse.author_options()
+    + argparse.message_options(save_template=False)
+    + argparse.sign_options()
+)
 
-directory = common.DirectoryHasRepositoryLib()
+directory = DirectoryHasRepository()
 
-def __create_commit(repository, tree, parents, options, message = ''):
+
+def __create_commit(repository, tree, parents, options, message=''):
     """Return a new Commit object."""
-    cd = git.CommitData(
-        tree = tree, parents = parents, message = message,
-        author = git.Person.author(), committer = git.Person.committer())
-    cd = common.update_commit_data(cd, options)
-
+    cd = CommitData(
+        tree=tree,
+        parents=parents,
+        message=message,
+        author=Person.author(),
+        committer=Person.committer(),
+    )
+    cd = update_commit_data(
+        cd,
+        message=options.message,
+        author=options.author(cd.author),
+        sign_str=options.sign_str,
+        edit=options.message is None,
+    )
     return repository.commit(cd)
 
+
 def __get_published(stack, tree):
     """Check the patches that were already published."""
-    trans = transaction.StackTransaction(stack, 'publish')
-    published = trans.check_merged(trans.applied, tree = tree, quiet = True)
+    trans = StackTransaction(stack, 'publish')
+    published = trans.check_merged(trans.applied, tree=tree, quiet=True)
     trans.abort()
-
     return published
 
+
 def __get_last(stack, tree):
     """Return the name of the last published patch."""
     for p in reversed(stack.patchorder.applied):
         pc = stack.patches.get(p).commit
         if tree.sha1 == pc.data.tree.sha1:
             return p
-
     return None
 
+
 def func(parser, options, args):
     """Publish the stack changes."""
+    out.warn('DEPRECATED: stg publish will be removed in a future version of StGit.')
     repository = directory.repository
     stack = repository.get_stack(options.branch)
 
     if not args:
-        public_ref = common.get_public_ref(stack.name)
+        public_ref = get_public_ref(stack.name)
     elif len(args) == 1:
         public_ref = args[0]
     else:
@@ -124,7 +158,7 @@ def func(parser, options, args):
     # just clone the stack if the public ref does not exist
     if not repository.refs.exists(public_ref):
         if options.unpublished or options.last:
-            raise common.CmdException('"%s" does not exist' % public_ref)
+            raise CmdException('"%s" does not exist' % public_ref)
         repository.refs.set(public_ref, stack.head, 'publish')
         out.info('Created "%s"' % public_ref)
         return
@@ -136,8 +170,9 @@ def func(parser, options, args):
     if options.last:
         last = __get_last(stack, public_tree)
         if not last:
-            raise common.CmdException('Unable to find the last published patch '
-                                      '(possibly rebased stack)')
+            raise CmdException(
+                'Unable to find the last published patch ' '(possibly rebased stack)'
+            )
         out.info('%s' % last)
         return
 
@@ -151,7 +186,12 @@ def func(parser, options, args):
         published = set(__get_published(stack, public_tree))
         for p in stack.patchorder.applied:
             if p not in published:
-                print(p)
+                out.stdout(p)
+        return
+
+    if options.overwrite:
+        repository.refs.set(public_ref, stack.head, 'publish')
+        out.info('Overwrote "%s"' % public_ref)
         return
 
     # check for rebased stack. In this case we emulate a merge with the stack
@@ -163,12 +203,17 @@ def func(parser, options, args):
         out.info('Fast-forwarded "%s"' % public_ref)
         return
     if stack.base not in merge_bases:
-        message = 'Merge %s into %s' % (repository.describe(stack.base).strip(),
-                                        utils.strip_prefix('refs/heads/',
-                                                           public_ref))
-        public_head = __create_commit(repository, stack.head.data.tree,
-                                      [public_head, stack.base], options,
-                                      message)
+        message = 'Merge %s into %s' % (
+            repository.describe(stack.base).strip(),
+            utils.strip_prefix('refs/heads/', public_ref),
+        )
+        public_head = __create_commit(
+            repository,
+            stack.head.data.tree,
+            [public_head, stack.base],
+            options,
+            message,
+        )
         repository.refs.set(public_ref, public_head, 'publish')
         out.info('Merged the stack base into "%s"' % public_ref)
         return
@@ -190,8 +235,9 @@ def func(parser, options, args):
 
     # create a new commit (only happens if no new patches are detected)
     if public_tree.sha1 != stack.head.data.tree.sha1:
-        public_head = __create_commit(repository, stack.head.data.tree,
-                                      [public_head], options)
+        public_head = __create_commit(
+            repository, stack.head.data.tree, [public_head], options
+        )
 
     # update the public head
     repository.refs.set(public_ref, public_head, 'publish')
