@@ -1,20 +1,15 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse
 from stgit.argparse import opt
-from stgit.commands.common import (CmdException,
-                                   DirectoryGotoToplevel,
-                                   check_conflicts,
-                                   check_head_top_equal,
-                                   check_local_changes,
-                                   git_id,
-                                   post_rebase,
-                                   prepare_rebase,
-                                   print_crt_patch,
-                                   rebase)
-from stgit.git import GitException
+from stgit.commands.common import (
+    CmdException,
+    DirectoryGotoTopLevel,
+    git_commit,
+    post_rebase,
+    prepare_rebase,
+    rebase,
+)
 
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
@@ -51,15 +46,23 @@ Or if you want to skip that patch:
         $ stg undo --hard
         $ stg push next-patch..top-patch"""
 
-args = [argparse.commit]
+args = ['commit']
 options = [
-    opt('-n', '--nopush', action = 'store_true',
-        short = 'Do not push the patches back after rebasing'),
-    opt('-m', '--merged', action = 'store_true',
-        short = 'Check for patches merged upstream')]
+    opt(
+        '-n',
+        '--nopush',
+        action='store_true',
+        short='Do not push the patches back after rebasing',
+    ),
+    opt(
+        '-m',
+        '--merged',
+        action='store_true',
+        short='Check for patches merged upstream',
+    ),
+]
 
-directory = DirectoryGotoToplevel(log=True)
-crt_series = None
+directory = DirectoryGotoTopLevel()
 
 
 def func(parser, options, args):
@@ -68,19 +71,21 @@ def func(parser, options, args):
     if len(args) != 1:
         parser.error('incorrect number of arguments')
 
-    if crt_series.get_protected():
+    repository = directory.repository
+    stack = repository.get_stack()
+    iw = repository.default_iw
+
+    if stack.protected:
         raise CmdException('This branch is protected. Rebase is not permitted')
 
-    check_local_changes()
-    check_conflicts()
-    check_head_top_equal(crt_series)
+    target = git_commit(args[0], repository)
 
-    # ensure an exception is raised before popping on non-existent target
-    if git_id(crt_series, args[0]) is None:
-        raise GitException('Unknown revision: %s' % args[0])
-        
-    applied = prepare_rebase(crt_series)
-    rebase(crt_series, args[0])
-    post_rebase(crt_series, applied, options.nopush, options.merged)
+    applied = stack.patchorder.applied
 
-    print_crt_patch(crt_series)
+    retval = prepare_rebase(stack, 'rebase')
+    if retval:
+        return retval
+
+    rebase(stack, iw, target)
+    if not options.nopush:
+        return post_rebase(stack, applied, 'rebase', check_merged=options.merged)
