@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from stgit.argparse import opt
-from stgit.commands import common
+from stgit.commands.common import CmdException, DirectoryHasRepository
 from stgit.lib import log, transaction
 
 __copyright__ = """
@@ -35,23 +34,33 @@ undo."""
 
 args = []
 options = [
-    opt('-n', '--number', type = 'int', metavar = 'N', default = 1,
-        short = 'Undo the last N undos'),
-    opt('--hard', action = 'store_true',
-        short = 'Discard changes in your index/worktree')]
+    opt(
+        '-n',
+        '--number',
+        type='int',
+        metavar='N',
+        default=1,
+        short='Undo the last N undos',
+    ),
+    opt('--hard', action='store_true', short='Discard changes in your index/worktree',),
+]
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     stack = directory.repository.current_stack
     if options.number < 1:
-        raise common.CmdException('Bad number of undos to redo')
+        raise CmdException('Bad number of undos to redo')
     state = log.undo_state(stack, -options.number)
-    trans = transaction.StackTransaction(stack, 'redo %d' % options.number,
-                                         discard_changes = options.hard,
-                                         allow_bad_head = True)
+    trans = transaction.StackTransaction(
+        stack,
+        'redo %d' % options.number,
+        discard_changes=options.hard,
+        allow_bad_head=True,
+    )
     try:
         log.reset_stack(trans, stack.repository.default_iw, state)
     except transaction.TransactionHalted:
         pass
-    return trans.run(stack.repository.default_iw, allow_bad_head = True)
+    return trans.run(stack.repository.default_iw, allow_bad_head=True)
