@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse
 from stgit.argparse import opt
 from stgit.commands.common import CmdException, DirectoryHasRepository
+from stgit.lib.log import log_entry
 from stgit.out import out
 
 __copyright__ = """
@@ -30,31 +29,34 @@ description = """
 Rename <oldpatch> into <newpatch> in a series. If <oldpatch> is not
 given, the top-most patch will be renamed."""
 
-args = [argparse.applied_patches, argparse.unapplied_patches,
-        argparse.hidden_patches]
+args = ['applied_patches', 'unapplied_patches', 'hidden_patches']
 options = [
-    opt('-b', '--branch', args = [argparse.stg_branches],
-        short = 'use BRANCH instead of the default one')]
+    opt(
+        '-b',
+        '--branch',
+        args=['stg_branches'],
+        short='use BRANCH instead of the default one',
+    )
+]
 
-directory = DirectoryHasRepository(log=True)
-crt_series = None
+directory = DirectoryHasRepository()
 
 
 def func(parser, options, args):
-    """Rename a patch in the series
-    """
-    crt = crt_series.get_current()
+    """Rename a patch in the series"""
+    stack = directory.repository.get_stack(options.branch)
 
     if len(args) == 2:
         old, new = args
     elif len(args) == 1:
-        if not crt:
+        if not stack.patchorder.applied:
             raise CmdException("No applied top patch to rename exists.")
-        old, [new] = crt, args
+        old = stack.patchorder.applied[-1]
+        new = args[0]
     else:
         parser.error('incorrect number of arguments')
 
     out.start('Renaming patch "%s" to "%s"' % (old, new))
-    crt_series.rename_patch(old, new)
-
+    stack.rename_patch(old, new)
+    log_entry(stack, 'rename %s to %s' % (old, new))
     out.done()
