@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse
-from stgit.argparse import opt
-from stgit.commands import common
+from stgit.argparse import keep_option, opt, patch_range
+from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
 from stgit.lib import transaction
 
 __copyright__ = """
@@ -42,20 +40,34 @@ including <target patch>), then pushing the patches to sink, and then
 (unless '--nopush' is also given) pushing back into place the
 formerly-applied patches."""
 
-args = [argparse.patch_range(argparse.applied_patches,
-                             argparse.unapplied_patches)]
-options = [
-    opt('-n', '--nopush', action = 'store_true',
-        short = 'Do not push the patches back after sinking', long = """
+args = [patch_range('applied_patches', 'unapplied_patches')]
+options = (
+    [
+        opt(
+            '-n',
+            '--nopush',
+            action='store_true',
+            short='Do not push the patches back after sinking',
+            long="""
         Do not push back on the stack the formerly-applied patches.
-        Only the patches to sink are pushed."""),
-    opt('-t', '--to', metavar = 'TARGET', args = [argparse.applied_patches],
-        short = 'Sink patches below the TARGET patch', long = """
+        Only the patches to sink are pushed.""",
+        ),
+        opt(
+            '-t',
+            '--to',
+            metavar='TARGET',
+            args=['applied_patches'],
+            short='Sink patches below the TARGET patch',
+            long="""
         Specify a target patch to place the patches below, instead of
-        sinking them to the bottom of the stack.""")
-    ] + argparse.keep_option()
+        sinking them to the bottom of the stack.""",
+        ),
+    ]
+    + keep_option()
+)
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Sink patches down the stack.
@@ -63,19 +75,18 @@ def func(parser, options, args):
     stack = directory.repository.current_stack
 
     if options.to and options.to not in stack.patchorder.applied:
-        raise common.CmdException('Cannot sink below %s since it is not applied'
-                                  % options.to)
+        raise CmdException('Cannot sink below %s since it is not applied' % options.to)
 
     if len(args) > 0:
-        patches = common.parse_patches(args, stack.patchorder.all)
+        patches = parse_patches(args, stack.patchorder.all)
     else:
         # current patch
         patches = list(stack.patchorder.applied[-1:])
 
     if not patches:
-        raise common.CmdException('No patches to sink')
+        raise CmdException('No patches to sink')
     if options.to and options.to in patches:
-        raise common.CmdException('Cannot have a sinked patch as target')
+        raise CmdException('Cannot have a sinked patch as target')
 
     applied = [p for p in stack.patchorder.applied if p not in patches]
     if options.to:
@@ -87,12 +98,10 @@ def func(parser, options, args):
 
     iw = stack.repository.default_iw
     clean_iw = (not options.keep and iw) or None
-    trans = transaction.StackTransaction(stack, 'sink',
-                                         check_clean_iw = clean_iw)
+    trans = transaction.StackTransaction(stack, 'sink', check_clean_iw=clean_iw)
 
     try:
-        trans.reorder_patches(applied, unapplied, iw = iw,
-                              allow_interactive = True)
+        trans.reorder_patches(applied, unapplied, iw=iw, allow_interactive=True)
     except transaction.TransactionHalted:
         pass
     return trans.run(iw)
