@@ -1,4 +1,15 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+from stgit import argparse, utils
+from stgit.argparse import opt, patch_range
+from stgit.commands.common import (
+    CmdException,
+    DirectoryHasRepository,
+    parse_patches,
+    run_commit_msg_hook,
+)
+from stgit.lib.transaction import StackTransaction, TransactionHalted
 
 __copyright__ = """
 Copyright (C) 2007, Karl Hasselström <kha@treskal.com>
@@ -16,12 +27,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
-from stgit.argparse import opt
-from stgit.out import *
-from stgit import argparse, utils
-from stgit.commands import common
-from stgit.lib import git, transaction
-
 help = 'Squash two or more patches into one'
 kind = 'stack'
 usage = ['[options] [--] <patches>']
@@ -45,68 +50,92 @@ Conflicts can occur whenever we push a patch; that is, in step (2) and
 (5). If there are conflicts, the command will stop so that you can
 resolve them."""
 
-args = [argparse.patch_range(argparse.applied_patches,
-                             argparse.unapplied_patches)]
-options = ([opt('-n', '--name', short = 'Name of squashed patch')] +
-           argparse.message_options(save_template = True) +
-           argparse.hook_options())
+args = [patch_range('applied_patches', 'unapplied_patches')]
+options = (
+    [opt('-n', '--name', short='Name of squashed patch')]
+    + argparse.message_options(save_template=True)
+    + argparse.hook_options()
+)
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 class SaveTemplateDone(Exception):
     pass
 
+
+def _append_comment(message, comment):
+    return '\n'.join(
+        [
+            message,
+            '',
+            '---',
+            'Everything following the line with "---" will be ignored',
+            '',
+            comment,
+        ]
+    )
+
+
+def _strip_comment(message):
+    try:
+        return message[: message.index('\n---\n')]
+    except ValueError:
+        return message
+
+
 def _squash_patches(trans, patches, msg, save_template, no_verify=False):
     cd = trans.patches[patches[0]].data
-    cd = git.CommitData(tree = cd.tree, parents = cd.parents)
     for pn in patches[1:]:
         c = trans.patches[pn]
         tree = trans.stack.repository.simple_merge(
-            base = c.data.parent.data.tree,
-            ours = cd.tree, theirs = c.data.tree)
+            base=c.data.parent.data.tree, ours=cd.tree, theirs=c.data.tree,
+        )
         if not tree:
             return None
         cd = cd.set_tree(tree)
-    if msg == None:
-        msg = utils.append_comment(
-            trans.patches[patches[0]].data.message,
-            '\n\n'.join('%s\n\n%s' % (pn.ljust(70, '-'),
-                                      trans.patches[pn].data.message)
-                        for pn in patches[1:]))
+    if msg is None:
+        msg = _append_comment(
+            cd.message_str,
+            '\n\n'.join(
+                '%s\n\n%s' % (pn.ljust(70, '-'), trans.patches[pn].data.message_str)
+                for pn in patches[1:]
+            ),
+        )
         if save_template:
-            save_template(msg)
+            save_template(msg.encode(cd.encoding))
             raise SaveTemplateDone()
         else:
             msg = utils.edit_string(msg, '.stgit-squash.txt')
-    msg = utils.strip_comment(msg).strip()
+    msg = _strip_comment(msg).strip()
     cd = cd.set_message(msg)
 
     if not no_verify:
-        cd = common.run_commit_msg_hook(trans.stack.repository, cd)
+        cd = run_commit_msg_hook(trans.stack.repository, cd)
 
     return cd
 
-def _squash(stack, iw, name, msg, save_template, patches, no_verify=False):
 
+def _squash(stack, iw, name, msg, save_template, patches, no_verify=False):
     # If a name was supplied on the command line, make sure it's OK.
     def bad_name(pn):
         return pn not in patches and stack.patches.exists(pn)
+
     def get_name(cd):
-        return name or utils.make_patch_name(cd.message, bad_name)
+        return name or utils.make_patch_name(cd.message_str, bad_name)
+
     if name and bad_name(name):
-        raise common.CmdException('Patch name "%s" already taken')
+        raise CmdException('Patch name "%s" already taken' % name)
 
     def make_squashed_patch(trans, new_commit_data):
         name = get_name(new_commit_data)
         trans.patches[name] = stack.repository.commit(new_commit_data)
         trans.unapplied.insert(0, name)
 
-    trans = transaction.StackTransaction(stack, 'squash',
-                                         allow_conflicts = True)
+    trans = StackTransaction(stack, 'squash', allow_conflicts=True)
     push_new_patch = bool(set(patches) & set(trans.applied))
     try:
-        new_commit_data = _squash_patches(trans, patches, msg, save_template,
-                                          no_verify)
+        new_commit_data = _squash_patches(trans, patches, msg, save_template, no_verify)
         if new_commit_data:
             # We were able to construct the squashed commit
             # automatically. So just delete its constituent patches.
@@ -118,9 +147,11 @@ def _squash(stack, iw, name, msg, save_template, patches, no_verify=False):
             to_push = trans.pop_patches(lambda pn: pn in patches)
             for pn in patches:
                 trans.push_patch(pn, iw)
-            new_commit_data = _squash_patches(trans, patches, msg,
-                                                save_template, no_verify)
-            assert not trans.delete_patches(lambda pn: pn in patches)
+            new_commit_data = _squash_patches(
+                trans, patches, msg, save_template, no_verify
+            )
+            popped_extra = trans.delete_patches(lambda pn: pn in patches)
+            assert not popped_extra
         make_squashed_patch(trans, new_commit_data)
 
         # Push the new patch if necessary, and any unrelated patches we've
@@ -132,15 +163,22 @@ def _squash(stack, iw, name, msg, save_template, patches, no_verify=False):
     except SaveTemplateDone:
         trans.abort(iw)
         return
-    except transaction.TransactionHalted:
+    except TransactionHalted:
         pass
     return trans.run(iw)
 
+
 def func(parser, options, args):
     stack = directory.repository.current_stack
-    patches = common.parse_patches(args, list(stack.patchorder.all))
+    patches = parse_patches(args, list(stack.patchorder.all))
     if len(patches) < 2:
-        raise common.CmdException('Need at least two patches')
-    return _squash(stack, stack.repository.default_iw, options.name,
-                   options.message, options.save_template, patches,
-                   options.no_verify)
+        raise CmdException('Need at least two patches')
+    return _squash(
+        stack,
+        stack.repository.default_iw,
+        options.name,
+        options.message,
+        options.save_template,
+        patches,
+        options.no_verify,
+    )
