@@ -1,3 +1,9 @@
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+from stgit.argparse import opt
+from stgit.commands.common import CmdException, DirectoryHasRepository
+from stgit.out import out
 
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
@@ -15,11 +21,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
-from stgit.argparse import opt
-from stgit.commands import common
-from stgit.out import out
-from stgit import argparse
-
 help = 'Print the name of the top patch'
 kind = 'stack'
 usage = ['']
@@ -28,10 +29,16 @@ Print the name of the current (topmost) patch."""
 
 args = []
 options = [
-    opt('-b', '--branch', args = [argparse.stg_branches],
-        short = 'Use BRANCH instead of the default branch')]
+    opt(
+        '-b',
+        '--branch',
+        args=['stg_branches'],
+        short='Use BRANCH instead of the default branch',
+    )
+]
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Show the name of the topmost patch
@@ -45,4 +52,4 @@ def func(parser, options, args):
     if applied:
         out.stdout(applied[-1])
     else:
-        raise common.CmdException, 'No patches applied'
+        raise CmdException('No patches applied')
