@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse, utils
+from stgit import utils
 from stgit.argparse import opt
-from stgit.commands import common
+from stgit.commands.common import CmdException, DirectoryHasRepository
 from stgit.lib import transaction
 from stgit.out import out
 
@@ -26,9 +25,11 @@ along with this program; if not, see http://www.gnu.org/licenses/.
 
 help = 'Turn regular git commits into StGit patches'
 kind = 'stack'
-usage = ['[--] <patch-name-1> [<patch-name-2> ...]',
-         '-n NUM [--] [<prefix>]',
-         '-t <committish> [-x]']
+usage = [
+    '[--] <patch-name-1> [<patch-name-2> ...]',
+    '-n NUM [--] [<prefix>]',
+    '-t <committish> [-x]',
+]
 description = """
 Take one or more git commits at the base of the current stack and turn
 them into StGIT patches. The new patches are created as applied patches
@@ -52,14 +53,20 @@ words, you can't uncommit a merge."""
 
 args = []
 options = [
-    opt('-n', '--number', type = 'int',
-        short = 'Uncommit the specified number of commits'),
-    opt('-t', '--to', args = [argparse.commit],
-        short = 'Uncommit to the specified commit'),
-    opt('-x', '--exclusive', action = 'store_true',
-        short = 'Exclude the commit specified by the --to option')]
+    opt(
+        '-n', '--number', type='int', short='Uncommit the specified number of commits',
+    ),
+    opt('-t', '--to', args=['commit'], short='Uncommit to the specified commit',),
+    opt(
+        '-x',
+        '--exclusive',
+        action='store_true',
+        short='Exclude the commit specified by the --to option',
+    ),
+]
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Uncommit a number of patches.
@@ -85,8 +92,7 @@ def func(parser, options, args):
             patchnames = None
         elif len(args) == 1:
             # prefix specified
-            patchnames = ['%s%d' % (args[0], i)
-                          for i in range(patch_nr, 0, -1)]
+            patchnames = ['%s%d' % (args[0], i) for i in range(patch_nr, 0, -1)]
         else:
             parser.error('when using --number, specify at most one patch name')
     elif len(args) == 0:
@@ -102,9 +108,9 @@ def func(parser, options, args):
             [next] = next
         except ValueError:
             out.done()
-            raise common.CmdException(
-                'Trying to uncommit %s, which does not have exactly one parent'
-                % n.sha1)
+            raise CmdException(
+                'Trying to uncommit %s, which does not have exactly one parent' % n.sha1
+            )
         return c.append(n)
 
     commits = []
@@ -132,22 +138,21 @@ def func(parser, options, args):
     if patchnames:
         for pn in patchnames:
             if pn in taken_names:
-                raise common.CmdException('Patch name "%s" already taken' % pn)
+                raise CmdException('Patch name "%s" already taken' % pn)
             taken_names.add(pn)
     else:
         patchnames = []
         for c in reversed(commits):
-            pn = utils.make_patch_name(c.data.message,
-                                       lambda pn: pn in taken_names)
+            pn = utils.make_patch_name(c.data.message_str, lambda pn: pn in taken_names)
             patchnames.append(pn)
             taken_names.add(pn)
         patchnames.reverse()
 
-    trans = transaction.StackTransaction(stack, 'uncommit',
-                                         allow_conflicts = True,
-                                         allow_bad_head = True)
+    trans = transaction.StackTransaction(
+        stack, 'uncommit', allow_conflicts=True, allow_bad_head=True
+    )
     for commit, pn in zip(commits, patchnames):
         trans.patches[pn] = commit
     trans.applied = list(reversed(patchnames)) + trans.applied
-    trans.run(set_head = False)
+    trans.run(set_head=False)
     out.done()
