@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from stgit import argparse
-from stgit.argparse import opt
-from stgit.commands import common
+from stgit.argparse import opt, patch_range
+from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
 from stgit.lib import transaction
 
 __copyright__ = """
@@ -30,12 +28,18 @@ description = """
 Unhide a hidden range of patches so that they are shown in the plain
 'stg series' command output."""
 
-args = [argparse.patch_range(argparse.hidden_patches)]
+args = [patch_range('hidden_patches')]
 options = [
-    opt('-b', '--branch', args = [argparse.stg_branches],
-        short = 'Use BRANCH instead of the default branch')]
+    opt(
+        '-b',
+        '--branch',
+        args=['stg_branches'],
+        short='Use BRANCH instead of the default branch',
+    )
+]
+
+directory = DirectoryHasRepository()
 
-directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Unhide a range of patch in the series."""
@@ -45,10 +49,10 @@ def func(parser, options, args):
     if not args:
         parser.error('No patches specified')
 
-    patches = common.parse_patches(args, trans.all_patches)
+    patches = parse_patches(args, trans.all_patches)
     for p in patches:
         if p not in trans.hidden:
-            raise common.CmdException('Patch "%s" not hidden' % p)
+            raise CmdException('Patch "%s" not hidden' % p)
 
     applied = list(trans.applied)
     unapplied = trans.unapplied + patches
