@@ -100,73 +100,62 @@ The simplified log is exactly like the full log, except that its only
 parent is the (simplified) previous log entry, if any. It's purpose is
 mainly ease of visualization."""
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-from io import StringIO
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import re
 
 from stgit import utils
-from stgit.exception import StgException, StackException
-from stgit.lib import git, stack as libstack
+from stgit.exception import StgException
+from stgit.lib.git import BlobData, CommitData, TreeData
+from stgit.lib.stack import StackRepository
 from stgit.out import out
 
 
 class LogException(StgException):
     pass
 
+
 class LogParseException(LogException):
     pass
 
 
-def patch_file(repo, cd):
-    metadata = '\n'.join([
-        'Bottom: %s' % cd.parent.data.tree.sha1,
-        'Top:    %s' % cd.tree.sha1,
-        'Author: %s' % cd.author.name_email,
-        'Date:   %s' % cd.author.date,
-        '',
-        cd.message,
-        '',
-        '---',
-        '',
-    ]).encode('utf-8')
-    diff = repo.diff_tree(cd.parent.data.tree, cd.tree, ['-M']).strip()
-    return repo.commit(git.BlobData(metadata + diff + b'\n'))
-
-
 def log_ref(branch):
     return 'refs/heads/%s.stgit' % branch
 
+
 class LogEntry(object):
-    __separator = '\n---\n'
-    __max_parents = 16
-    def __init__(self, repo, prev, head, applied, unapplied, hidden,
-                 patches, message):
-        self.__repo = repo
-        self.__prev = prev
-        self.__simplified = None
+    _max_parents = 16
+
+    def __init__(self, repo, prev, head, applied, unapplied, hidden, patches, message):
+        self._repo = repo
+        self._prev = prev
+        self._simplified = None
         self.head = head
         self.applied = applied
         self.unapplied = unapplied
         self.hidden = hidden
         self.patches = patches
         self.message = message
+
     @property
     def simplified(self):
-        if not self.__simplified:
-            self.__simplified = self.commit.data.parents[0]
-        return self.__simplified
+        if not self._simplified:
+            self._simplified = self.commit.data.parents[0]
+        return self._simplified
+
     @property
     def prev(self):
-        if self.__prev is not None and not isinstance(self.__prev, LogEntry):
-            self.__prev = self.from_commit(self.__repo, self.__prev)
-        return self.__prev
+        if self._prev is not None and not isinstance(self._prev, LogEntry):
+            self._prev = self.from_commit(self._repo, self._prev)
+        return self._prev
+
     @property
     def base(self):
         if self.applied:
             return self.patches[self.applied[0]].data.parent
         else:
             return self.head
+
     @property
     def top(self):
         if self.applied:
@@ -181,17 +170,20 @@ class LogEntry(object):
     @classmethod
     def from_stack(cls, prev, stack, message):
         return cls(
-            repo = stack.repository,
-            prev = prev,
-            head = stack.head,
-            applied = list(stack.patchorder.applied),
-            unapplied = list(stack.patchorder.unapplied),
-            hidden = list(stack.patchorder.hidden),
-            patches = dict((pn, stack.patches.get(pn).commit)
-                           for pn in stack.patchorder.all),
-            message = message)
+            repo=stack.repository,
+            prev=prev,
+            head=stack.head,
+            applied=list(stack.patchorder.applied),
+            unapplied=list(stack.patchorder.unapplied),
+            hidden=list(stack.patchorder.hidden),
+            patches=dict(
+                (pn, stack.patches.get(pn).commit) for pn in stack.patchorder.all
+            ),
+            message=message,
+        )
+
     @staticmethod
-    def __parse_metadata(repo, metadata):
+    def _parse_metadata(repo, metadata):
         """Parse a stack log metadata string."""
         if not metadata.startswith('Version:'):
             raise LogParseException('Malformed log metadata')
@@ -200,8 +192,7 @@ class LogEntry(object):
         try:
             version = int(version_str)
         except ValueError:
-            raise LogParseException(
-                'Malformed version number: %r' % version_str)
+            raise LogParseException('Malformed version number: %r' % version_str)
         if version < 1:
             raise LogException('Log is version %d, which is too old' % version)
         if version > 1:
@@ -224,90 +215,134 @@ class LogEntry(object):
         else:
             prev = repo.get_commit(prev)
         head = repo.get_commit(parsed['Head'])
-        lists = { 'Applied': [], 'Unapplied': [], 'Hidden': [] }
+        lists = {'Applied': [], 'Unapplied': [], 'Hidden': []}
         patches = {}
         for lst in lists:
             for entry in parsed[lst]:
                 pn, sha1 = [x.strip() for x in entry.split(':')]
                 lists[lst].append(pn)
                 patches[pn] = repo.get_commit(sha1)
-        return (prev, head, lists['Applied'], lists['Unapplied'],
-                lists['Hidden'], patches)
+        return (
+            prev,
+            head,
+            lists['Applied'],
+            lists['Unapplied'],
+            lists['Hidden'],
+            patches,
+        )
+
     @classmethod
     def from_commit(cls, repo, commit):
         """Parse a (full or simplified) stack log commit."""
-        message = commit.data.message
+        message = commit.data.message_str
         try:
-            perm, meta = commit.data.tree.data.entries['meta']
+            perm, meta = commit.data.tree.data['meta']
         except KeyError:
             raise LogParseException('Not a stack log')
-        (prev, head, applied, unapplied, hidden, patches
-         ) = cls.__parse_metadata(repo, meta.data.bytes.decode('utf-8'))
+        (prev, head, applied, unapplied, hidden, patches) = cls._parse_metadata(
+            repo, meta.data.bytes.decode('utf-8')
+        )
         lg = cls(repo, prev, head, applied, unapplied, hidden, patches, message)
         lg.commit = commit
         return lg
-    def __metadata_string(self):
-        e = StringIO()
-        e.write('Version: 1\n')
-        if self.prev is None:
-            e.write('Previous: None\n')
-        else:
-            e.write('Previous: %s\n' % self.prev.commit.sha1)
-        e.write('Head: %s\n' % self.head.sha1)
-        for lst, title in [(self.applied, 'Applied'),
-                           (self.unapplied, 'Unapplied'),
-                           (self.hidden, 'Hidden')]:
-            e.write('%s:\n' % title)
+
+    def _metadata_string(self):
+        lines = ['Version: 1']
+        lines.append(
+            'Previous: %s' % ('None' if self.prev is None else self.prev.commit.sha1)
+        )
+        lines.append('Head: %s' % self.head.sha1)
+        for lst, title in [
+            (self.applied, 'Applied'),
+            (self.unapplied, 'Unapplied'),
+            (self.hidden, 'Hidden'),
+        ]:
+            lines.append('%s:' % title)
             for pn in lst:
-                e.write('  %s: %s\n' % (pn, self.patches[pn].sha1))
-        return e.getvalue()
-    def __parents(self):
+                lines.append('  %s: %s' % (pn, self.patches[pn].sha1))
+        return '\n'.join(lines)
+
+    def _parents(self):
         """Return the set of parents this log entry needs in order to be a
         descendant of all the commits it refers to."""
-        xp = set([self.head]) | set(self.patches[pn]
-                                    for pn in self.unapplied + self.hidden)
+        xp = set([self.head]) | set(
+            self.patches[pn] for pn in self.unapplied + self.hidden
+        )
         if self.applied:
             xp.add(self.patches[self.applied[-1]])
         if self.prev is not None:
             xp.add(self.prev.commit)
             xp -= set(self.prev.patches.values())
         return xp
-    def __tree(self, metadata):
+
+    def patch_file(self, cd):
+        metadata = '\n'.join(
+            [
+                'Bottom: %s' % cd.parent.data.tree.sha1,
+                'Top:    %s' % cd.tree.sha1,
+                'Author: %s' % cd.author.name_email,
+                'Date:   %s' % cd.author.date,
+                '',
+                cd.message_str,
+            ]
+        ).encode('utf-8')
+        return self._repo.commit(BlobData(metadata))
+
+    def _tree(self, metadata):
         if self.prev is None:
+
             def pf(c):
-                return patch_file(self.__repo, c.data)
+                return self.patch_file(c.data)
+
         else:
             prev_top_tree = self.prev.commit.data.tree
-            perm, prev_patch_tree = prev_top_tree.data.entries['patches']
+            perm, prev_patch_tree = prev_top_tree.data['patches']
             # Map from Commit object to patch_file() results taken
             # from the previous log entry.
-            c2b = dict((self.prev.patches[pn], pf) for pn, pf
-                       in prev_patch_tree.data.entries.items())
+            c2b = dict((self.prev.patches[pn], pf) for pn, pf in prev_patch_tree.data)
+
             def pf(c):
                 r = c2b.get(c, None)
                 if not r:
-                    r = patch_file(self.__repo, c.data)
+                    r = self.patch_file(c.data)
                 return r
+
         patches = dict((pn, pf(c)) for pn, c in self.patches.items())
-        return self.__repo.commit(git.TreeData({
-                    'meta': self.__repo.commit(git.BlobData(metadata.encode('utf-8'))),
-                    'patches': self.__repo.commit(git.TreeData(patches)) }))
+        return self._repo.commit(
+            TreeData(
+                {
+                    'meta': self._repo.commit(BlobData(metadata.encode('utf-8'))),
+                    'patches': self._repo.commit(TreeData(patches)),
+                }
+            )
+        )
+
     def write_commit(self):
-        metadata = self.__metadata_string()
-        tree = self.__tree(metadata)
-        self.__simplified = self.__repo.commit(git.CommitData(
-                tree = tree, message = self.message,
-                parents = [prev.simplified for prev in [self.prev]
-                           if prev is not None]))
-        parents = list(self.__parents())
-        while len(parents) >= self.__max_parents:
-            g = self.__repo.commit(git.CommitData(
-                    tree = tree, parents = parents[-self.__max_parents:],
-                    message = 'Stack log parent grouping'))
-            parents[-self.__max_parents:] = [g]
-        self.commit = self.__repo.commit(git.CommitData(
-                tree = tree, message = self.message,
-                parents = [self.simplified] + parents))
+        metadata = self._metadata_string()
+        tree = self._tree(metadata)
+        self._simplified = self._repo.commit(
+            CommitData(
+                tree=tree,
+                message=self.message,
+                parents=[prev.simplified for prev in [self.prev] if prev is not None],
+            )
+        )
+        parents = list(self._parents())
+        while len(parents) >= self._max_parents:
+            g = self._repo.commit(
+                CommitData(
+                    tree=tree,
+                    parents=parents[-self._max_parents :],
+                    message='Stack log parent grouping',
+                )
+            )
+            parents[-self._max_parents :] = [g]
+        self.commit = self._repo.commit(
+            CommitData(
+                tree=tree, message=self.message, parents=[self.simplified] + parents,
+            )
+        )
+
 
 def get_log_entry(repo, ref, commit):
     try:
@@ -315,12 +350,16 @@ def get_log_entry(repo, ref, commit):
     except LogException as e:
         raise LogException('While reading log from %s: %s' % (ref, e))
 
+
 def same_state(log1, log2):
     """Check whether two log entries describe the same current state."""
-    s = [[lg.head, lg.applied, lg.unapplied, lg.hidden, lg.patches]
-         for lg in [log1, log2]]
+    s = [
+        [lg.head, lg.applied, lg.unapplied, lg.hidden, lg.patches]
+        for lg in [log1, log2]
+    ]
     return s[0] == s[1]
 
+
 def log_entry(stack, msg):
     """Write a new log entry for the stack."""
     ref = log_ref(stack.name)
@@ -342,54 +381,13 @@ def log_entry(stack, msg):
     new_log.write_commit()
     stack.repository.refs.set(ref, new_log.commit, msg)
 
-class Fakestack(object):
-    """Imitates a real L{Stack<stgit.lib.stack.Stack>}, but with the
-    topmost patch popped."""
-    def __init__(self, stack):
-        appl = list(stack.patchorder.applied)
-        unappl = list(stack.patchorder.unapplied)
-        hidd = list(stack.patchorder.hidden)
-        class patchorder(object):
-            applied = appl[:-1]
-            unapplied = [appl[-1]] + unappl
-            hidden = hidd
-            all = appl + unappl + hidd
-        self.patchorder = patchorder
-        class patches(object):
-            @staticmethod
-            def get(pn):
-                if pn == appl[-1]:
-                    class patch(object):
-                        commit = stack.patches.get(pn).old_commit
-                    return patch
-                else:
-                    return stack.patches.get(pn)
-        self.patches = patches
-        self.head = stack.head.data.parent
-        self.top = stack.top.data.parent
-        self.base = stack.base
-        self.name = stack.name
-        self.repository = stack.repository
-def compat_log_entry(msg):
-    """Write a new log entry. (Convenience function intended for use by
-    code not yet converted to the new infrastructure.)"""
-    try:
-        repo = default_repo()
-        stack = repo.get_stack(repo.current_branch_name)
-    except (StackException, git.RepositoryException) as e:
-        out.warn(str(e), 'Could not write to stack log')
-    else:
-        if repo.default_index.conflicts() and stack.patchorder.applied:
-            log_entry(Fakestack(stack), msg)
-            log_entry(stack, msg + ' (CONFLICT)')
-        else:
-            log_entry(stack, msg)
 
 def delete_log(repo, branch):
     ref = log_ref(branch)
     if repo.refs.exists(ref):
         repo.refs.delete(ref)
 
+
 def rename_log(repo, old_branch, new_branch, msg):
     old_ref = log_ref(old_branch)
     new_ref = log_ref(new_branch)
@@ -397,14 +395,17 @@ def rename_log(repo, old_branch, new_branch, msg):
         repo.refs.set(new_ref, repo.refs.get(old_ref), msg)
         repo.refs.delete(old_ref)
 
+
 def copy_log(repo, src_branch, dst_branch, msg):
     src_ref = log_ref(src_branch)
     dst_ref = log_ref(dst_branch)
     if repo.refs.exists(src_ref):
         repo.refs.set(dst_ref, repo.refs.get(src_ref), msg)
 
+
 def default_repo():
-    return libstack.Repository.default()
+    return StackRepository.default()
+
 
 def reset_stack(trans, iw, state):
     """Reset the stack to a given previous state."""
@@ -418,6 +419,7 @@ def reset_stack(trans, iw, state):
     trans.base = state.base
     trans.head = state.head
 
+
 def reset_stack_partially(trans, iw, state, only_patches):
     """Reset the stack to a given previous state -- but only the given
     patches, not anything else.
@@ -440,6 +442,7 @@ def reset_stack_partially(trans, iw, state, only_patches):
         if trans.patches[pn] != state.patches.get(pn, None):
             return True
         return False
+
     trans.pop_patches(mod)
 
     # Delete and modify/create patches. We've previously popped all
@@ -466,6 +469,7 @@ def reset_stack_partially(trans, iw, state, only_patches):
         if pn in pushable:
             trans.push_patch(pn, iw)
 
+
 def undo_state(stack, undo_steps):
     """Find the log entry C{undo_steps} steps in the past. (Successive
     undo operations are supposed to "add up", so if we find other undo
@@ -504,6 +508,7 @@ def undo_state(stack, undo_steps):
         log = log.prev
     return log
 
+
 def log_external_mods(stack):
     ref = log_ref(stack.name)
     try:
@@ -520,19 +525,13 @@ def log_external_mods(stack):
     if log.head == stack.head:
         # No external modifications.
         return
-    log_entry(stack, '\n'.join([
-                'external modifications', '',
-                'Modifications by tools other than StGit (e.g. git).']))
-
-def compat_log_external_mods():
-    try:
-        repo = default_repo()
-    except git.RepositoryException:
-        # No repository, so we couldn't log even if we wanted to.
-        return
-    try:
-        stack = repo.get_stack(repo.current_branch_name)
-    except StgException:
-        # Stack doesn't exist, so we can't log.
-        return
-    log_external_mods(stack)
+    log_entry(
+        stack,
+        '\n'.join(
+            [
+                'external modifications',
+                '',
+                'Modifications by tools other than StGit (e.g. git).',
+            ]
+        ),
+    )
