@@ -2,14 +2,15 @@
 """The L{StackTransaction} class makes it possible to make complex
 updates to an StGit stack in a safe and convenient way."""
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 from itertools import takewhile
 import atexit
 
 from stgit import exception, utils
 from stgit.config import config
-from stgit.lib import git, log
+from stgit.lib.git import CheckoutException, MergeConflictException, MergeException
+from stgit.lib.log import log_entry, log_external_mods
 from stgit.out import out
 
 
@@ -17,14 +18,17 @@ class TransactionException(exception.StgException):
     """Exception raised when something goes wrong with a
     L{StackTransaction}."""
 
+
 class TransactionHalted(TransactionException):
     """Exception raised when a L{StackTransaction} stops part-way through.
     Used to make a non-local jump from the transaction setup to the
     part of the transaction code where the transaction is run."""
 
+
 def _print_current_patch(old_applied, new_applied):
     def now_at(pn):
         out.info('Now at patch "%s"' % pn)
+
     if not old_applied and not new_applied:
         pass
     elif not old_applied:
@@ -36,16 +40,20 @@ def _print_current_patch(old_applied, new_applied):
     else:
         now_at(new_applied[-1])
 
+
 class _TransPatchMap(dict):
     """Maps patch names to Commit objects."""
+
     def __init__(self, stack):
         dict.__init__(self)
-        self.__stack = stack
+        self._stack = stack
+
     def __getitem__(self, pn):
         try:
             return dict.__getitem__(self, pn)
         except KeyError:
-            return self.__stack.patches.get(pn).commit
+            return self._stack.patches.get(pn).commit
+
 
 class StackTransaction(object):
     """A stack transaction, used for making complex updates to an StGit
@@ -78,214 +86,213 @@ class StackTransaction(object):
       method. This will either succeed in writing the updated state to
       your refs and index+worktree, or fail without having done
       anything."""
-    def __init__(self, stack, msg, discard_changes = False,
-                 allow_conflicts = False, allow_bad_head = False,
-                 check_clean_iw = None):
+
+    def __init__(
+        self,
+        stack,
+        msg,
+        discard_changes=False,
+        allow_conflicts=False,
+        allow_bad_head=False,
+        check_clean_iw=None,
+    ):
         """Create a new L{StackTransaction}.
 
         @param discard_changes: Discard any changes in index+worktree
         @type discard_changes: bool
         @param allow_conflicts: Whether to allow pre-existing conflicts
         @type allow_conflicts: bool or function of L{StackTransaction}"""
-        self.__stack = stack
-        self.__msg = msg
-        self.__patches = _TransPatchMap(stack)
-        self.__applied = list(self.__stack.patchorder.applied)
-        self.__unapplied = list(self.__stack.patchorder.unapplied)
-        self.__hidden = list(self.__stack.patchorder.hidden)
-        self.__error = None
-        self.__current_tree = self.__stack.head.data.tree
-        self.__base = self.__stack.base
-        self.__discard_changes = discard_changes
-        self.__bad_head = None
-        self.__conflicts = None
+        self.stack = stack
+        self._msg = msg
+        self.patches = _TransPatchMap(stack)
+        self._applied = list(self.stack.patchorder.applied)
+        self._unapplied = list(self.stack.patchorder.unapplied)
+        self._hidden = list(self.stack.patchorder.hidden)
+        self._error = None
+        self._current_tree = self.stack.head.data.tree
+        self._base = self.stack.base
+        self._discard_changes = discard_changes
+        self._bad_head = None
+        self._conflicts = None
         if isinstance(allow_conflicts, bool):
-            self.__allow_conflicts = lambda trans: allow_conflicts
+            self._allow_conflicts = lambda trans: allow_conflicts
         else:
-            self.__allow_conflicts = allow_conflicts
-        self.__temp_index = self.temp_index_tree = None
+            self._allow_conflicts = allow_conflicts
+        self._temp_index = self.temp_index_tree = None
         if not allow_bad_head:
-            self.__assert_head_top_equal()
+            self._assert_head_top_equal()
         if check_clean_iw:
-            self.__assert_index_worktree_clean(check_clean_iw)
-
-    @property
-    def stack(self):
-        return self.__stack
-
-    @property
-    def patches(self):
-        return self.__patches
+            self._assert_index_worktree_clean(check_clean_iw)
 
     @property
     def applied(self):
-        return self.__applied
+        return self._applied
 
     @applied.setter
     def applied(self, value):
-        self.__applied = list(value)
+        self._applied = list(value)
 
     @property
     def unapplied(self):
-        return self.__unapplied
+        return self._unapplied
 
     @unapplied.setter
     def unapplied(self, value):
-        self.__unapplied = list(value)
+        self._unapplied = list(value)
 
     @property
     def hidden(self):
-        return self.__hidden
+        return self._hidden
 
     @hidden.setter
     def hidden(self, value):
-        self.__hidden = list(value)
+        self._hidden = list(value)
 
     @property
     def all_patches(self):
-        return self.__applied + self.__unapplied + self.__hidden
+        return self._applied + self._unapplied + self._hidden
 
     @property
     def base(self):
-        return self.__base
+        return self._base
 
     @base.setter
     def base(self, value):
-        assert (not self.__applied
-                or self.patches[self.applied[0]].data.parent == value)
-        self.__base = value
+        assert not self._applied or self.patches[self.applied[0]].data.parent == value
+        self._base = value
 
     @property
     def temp_index(self):
-        if not self.__temp_index:
-            self.__temp_index = self.__stack.repository.temp_index()
-            atexit.register(self.__temp_index.delete)
-        return self.__temp_index
+        if not self._temp_index:
+            self._temp_index = self.stack.repository.temp_index()
+            atexit.register(self._temp_index.delete)
+        return self._temp_index
 
     @property
     def top(self):
-        if self.__applied:
-            return self.__patches[self.__applied[-1]]
+        if self._applied:
+            return self.patches[self._applied[-1]]
         else:
-            return self.__base
+            return self._base
 
     @property
     def head(self):
-        if self.__bad_head:
-            return self.__bad_head
+        if self._bad_head:
+            return self._bad_head
         else:
             return self.top
 
     @head.setter
     def head(self, value):
-        self.__bad_head = value
+        self._bad_head = value
 
-    def __assert_head_top_equal(self):
-        if not self.__stack.head_top_equal():
+    def _assert_head_top_equal(self):
+        if not self.stack.head_top_equal():
             out.error(
                 'HEAD and top are not the same.',
                 'This can happen if you modify a branch with git.',
-                '"stg repair --help" explains more about what to do next.')
-            self.__abort()
-    def __assert_index_worktree_clean(self, iw):
+                '"stg repair --help" explains more about what to do next.',
+            )
+            self._abort()
+
+    def _assert_index_worktree_clean(self, iw):
         if not iw.worktree_clean():
-            self.__halt('Worktree not clean. Use "refresh" or "reset --hard"')
+            self._halt('Worktree not clean. Use "refresh" or "reset --hard"')
         if not iw.index.is_clean(self.stack.head):
-            self.__halt('Index not clean. Use "refresh" or "reset --hard"')
-    def __checkout(self, tree, iw, allow_bad_head):
+            self._halt('Index not clean. Use "refresh" or "reset --hard"')
+
+    def _checkout(self, tree, iw, allow_bad_head):
         if not allow_bad_head:
-            self.__assert_head_top_equal()
-        if self.__current_tree == tree and not self.__discard_changes:
+            self._assert_head_top_equal()
+        if self._current_tree == tree and not self._discard_changes:
             # No tree change, but we still want to make sure that
             # there are no unresolved conflicts. Conflicts
             # conceptually "belong" to the topmost patch, and just
             # carrying them along to another patch is confusing.
-            if (self.__allow_conflicts(self) or iw is None
-                or not iw.index.conflicts()):
+            if self._allow_conflicts(self) or iw is None or not iw.index.conflicts():
                 return
             out.error('Need to resolve conflicts first')
-            self.__abort()
+            self._abort()
         assert iw is not None
-        if self.__discard_changes:
+        if self._discard_changes:
             iw.checkout_hard(tree)
         else:
-            iw.checkout(self.__current_tree, tree)
-        self.__current_tree = tree
+            iw.checkout(self._current_tree, tree)
+        self._current_tree = tree
+
     @staticmethod
-    def __abort():
-        raise TransactionException(
-            'Command aborted (all changes rolled back)')
-    def __check_consistency(self):
+    def _abort():
+        raise TransactionException('Command aborted (all changes rolled back)')
+
+    def _check_consistency(self):
         remaining = set(self.all_patches)
-        for pn, commit in self.__patches.items():
+        for pn, commit in self.patches.items():
             if commit is None:
-                assert self.__stack.patches.exists(pn)
+                assert self.stack.patches.exists(pn)
             else:
                 assert pn in remaining
-    def abort(self, iw = None):
+
+    def abort(self, iw=None):
         # The only state we need to restore is index+worktree.
         if iw:
-            self.__checkout(self.__stack.head.data.tree, iw,
-                            allow_bad_head = True)
-    def run(self, iw = None, set_head = True, allow_bad_head = False,
-            print_current_patch = True):
+            self._checkout(self.stack.head.data.tree, iw, allow_bad_head=True)
+
+    def run(
+        self, iw=None, set_head=True, allow_bad_head=False, print_current_patch=True
+    ):
         """Execute the transaction. Will either succeed, or fail (with an
         exception) and do nothing."""
-        self.__check_consistency()
-        log.log_external_mods(self.__stack)
+        self._check_consistency()
+        log_external_mods(self.stack)
         new_head = self.head
 
         # Set branch head.
         if set_head:
             if iw:
                 try:
-                    self.__checkout(new_head.data.tree, iw, allow_bad_head)
-                except git.CheckoutException:
+                    self._checkout(new_head.data.tree, iw, allow_bad_head)
+                except CheckoutException:
                     # We have to abort the transaction.
                     self.abort(iw)
-                    self.__abort()
-            self.__stack.set_head(new_head, self.__msg)
+                    self._abort()
+            self.stack.set_head(new_head, self._msg)
 
-        if self.__error:
-            if self.__conflicts:
-                out.error(*([self.__error] + self.__conflicts))
+        if self._error:
+            if self._conflicts:
+                out.error(*([self._error] + self._conflicts))
             else:
-                out.error(self.__error)
+                out.error(self._error)
+
+        old_applied = self.stack.patchorder.applied
+        msg = self._msg + (' (CONFLICT)' if self._conflicts else '')
 
         # Write patches.
-        def write(msg):
-            for pn, commit in self.__patches.items():
-                if self.__stack.patches.exists(pn):
-                    p = self.__stack.patches.get(pn)
-                    if commit is None:
-                        p.delete()
-                    else:
-                        p.set_commit(commit, msg)
+        for pn, commit in self.patches.items():
+            if self.stack.patches.exists(pn):
+                p = self.stack.patches.get(pn)
+                if commit is None:
+                    p.delete()
                 else:
-                    self.__stack.patches.new(pn, commit, msg)
-            self.__stack.patchorder.applied = self.__applied
-            self.__stack.patchorder.unapplied = self.__unapplied
-            self.__stack.patchorder.hidden = self.__hidden
-            log.log_entry(self.__stack, msg)
-        old_applied = self.__stack.patchorder.applied
-        if not self.__conflicts:
-            write(self.__msg)
-        else:
-            write(self.__msg + ' (CONFLICT)')
-        if print_current_patch:
-            _print_current_patch(old_applied, self.__applied)
+                    p.set_commit(commit, msg)
+            else:
+                self.stack.patches.new(pn, commit, msg)
+        self.stack.patchorder.set_order(self._applied, self._unapplied, self._hidden)
+        log_entry(self.stack, msg)
 
-        if self.__error:
+        if print_current_patch:
+            _print_current_patch(old_applied, self._applied)
+
+        if self._error:
             return utils.STGIT_CONFLICT
         else:
             return utils.STGIT_SUCCESS
 
-    def __halt(self, msg):
-        self.__error = msg
+    def _halt(self, msg):
+        self._error = msg
         raise TransactionHalted(msg)
 
     @staticmethod
-    def __print_popped(popped):
+    def _print_popped(popped):
         if len(popped) == 0:
             pass
         elif len(popped) == 1:
@@ -306,10 +313,10 @@ class StackTransaction(object):
         popped1 = [pn for pn in popped if not p(pn)]
         popped2 = [pn for pn in popped if p(pn)]
         self.unapplied = popped1 + popped2 + self.unapplied
-        self.__print_popped(popped)
+        self._print_popped(popped)
         return popped1
 
-    def delete_patches(self, p, quiet = False):
+    def delete_patches(self, p, quiet=False):
         """Delete all patches pn for which p(pn) is true. Return the list of
         other patches that had to be popped to accomplish this. Always
         succeeds."""
@@ -323,7 +330,7 @@ class StackTransaction(object):
         popped = [pn for pn in popped if not p(pn)]
         self.unapplied = popped + [pn for pn in self.unapplied if not p(pn)]
         self.hidden = [pn for pn in self.hidden if not p(pn)]
-        self.__print_popped(popped)
+        self._print_popped(popped)
         for pn in all_patches:
             if p(pn):
                 s = ['', ' (empty)'][self.patches[pn].data.is_nochange()]
@@ -332,8 +339,7 @@ class StackTransaction(object):
                     out.info('Deleted %s%s' % (pn, s))
         return popped
 
-    def push_patch(self, pn, iw = None, allow_interactive = False,
-                   already_merged = False):
+    def push_patch(self, pn, iw=None, allow_interactive=False, already_merged=False):
         """Attempt to push the named patch. If this results in conflicts,
         halts the transaction. If index+worktree are given, spill any
         conflicts to them."""
@@ -350,34 +356,36 @@ class StackTransaction(object):
             ours = cd.parent.data.tree
             theirs = cd.tree
             tree, self.temp_index_tree = self.temp_index.merge(
-                base, ours, theirs, self.temp_index_tree)
+                base, ours, theirs, self.temp_index_tree
+            )
         s = ''
         merge_conflict = False
         if not tree:
             if iw is None:
-                self.__halt('%s does not apply cleanly' % pn)
+                self._halt('%s does not apply cleanly' % pn)
             try:
-                self.__checkout(ours, iw, allow_bad_head = False)
-            except git.CheckoutException:
-                self.__halt('Index/worktree dirty')
+                self._checkout(ours, iw, allow_bad_head=False)
+            except CheckoutException:
+                self._halt('Index/worktree dirty')
             try:
-                interactive = (allow_interactive and
-                               config.getbool('stgit.autoimerge'))
-                iw.merge(base, ours, theirs, interactive = interactive)
+                interactive = allow_interactive and config.getbool('stgit.autoimerge')
+                iw.merge(base, ours, theirs, interactive=interactive)
                 tree = iw.index.write_tree()
-                self.__current_tree = tree
+                self._current_tree = tree
                 s = 'modified'
-            except git.MergeConflictException as e:
+            except MergeConflictException as e:
                 tree = ours
                 merge_conflict = True
-                self.__conflicts = e.conflicts
+                self._conflicts = e.conflicts
                 s = 'conflict'
-            except git.MergeException as e:
-                self.__halt(str(e))
+            except MergeException as e:
+                self._halt(str(e))
         cd = cd.set_tree(tree)
-        if any(getattr(cd, a) != getattr(orig_cd, a) for a in
-               ['parent', 'tree', 'author', 'message']):
-            comm = self.__stack.repository.commit(cd)
+        if any(
+            getattr(cd, a) != getattr(orig_cd, a)
+            for a in ['parent', 'tree', 'author', 'message']
+        ):
+            comm = self.stack.repository.commit(cd)
             if merge_conflict:
                 # When we produce a conflict, we'll run the update()
                 # function defined below _after_ having done the
@@ -397,7 +405,7 @@ class StackTransaction(object):
         if merge_conflict:
             # We've just caused conflicts, so we must allow them in
             # the final checkout.
-            self.__allow_conflicts = lambda trans: True
+            self._allow_conflicts = lambda trans: True
 
         # Update the stack state
         if comm:
@@ -410,7 +418,7 @@ class StackTransaction(object):
         self.applied.append(pn)
 
         if merge_conflict:
-            self.__halt("%d merge conflict(s)" % len(self.__conflicts))
+            self._halt("%d merge conflict(s)" % len(self._conflicts))
 
     def push_tree(self, pn):
         """Push the named patch without updating its tree."""
@@ -418,9 +426,11 @@ class StackTransaction(object):
         cd = orig_cd.set_committer(None).set_parent(self.top)
 
         s = ''
-        if any(getattr(cd, a) != getattr(orig_cd, a) for a in
-               ['parent', 'tree', 'author', 'message']):
-            self.patches[pn] = self.__stack.repository.commit(cd)
+        if any(
+            getattr(cd, a) != getattr(orig_cd, a)
+            for a in ['parent', 'tree', 'author', 'message']
+        ):
+            self.patches[pn] = self.stack.repository.commit(cd)
         else:
             s = ' (unmodified)'
         if cd.is_nochange():
@@ -434,17 +444,19 @@ class StackTransaction(object):
         del x[x.index(pn)]
         self.applied.append(pn)
 
-    def reorder_patches(self, applied, unapplied, hidden = None, iw = None,
-                        allow_interactive = False):
+    def reorder_patches(
+        self, applied, unapplied, hidden=None, iw=None, allow_interactive=False
+    ):
         """Push and pop patches to attain the given ordering."""
         if hidden is None:
             hidden = self.hidden
-        common = len(list(takewhile(lambda a: a[0] == a[1],
-                                    zip(self.applied, applied))))
+        common = len(
+            list(takewhile(lambda a: a[0] == a[1], zip(self.applied, applied)))
+        )
         to_pop = set(self.applied[common:])
         self.pop_patches(lambda pn: pn in to_pop)
         for pn in applied[common:]:
-            self.push_patch(pn, iw, allow_interactive = allow_interactive)
+            self.push_patch(pn, iw, allow_interactive=allow_interactive)
 
         # We only get here if all the pushes succeeded.
         assert self.applied == applied
@@ -452,7 +464,7 @@ class StackTransaction(object):
         self.unapplied = unapplied
         self.hidden = hidden
 
-    def check_merged(self, patches, tree = None, quiet = False):
+    def check_merged(self, patches, tree=None, quiet=False):
         """Return a subset of patches already merged."""
         if not quiet:
             out.start('Checking for patches merged upstream')
@@ -469,13 +481,14 @@ class StackTransaction(object):
             if cd.is_nochange():
                 continue
             try:
-                self.temp_index.apply_treediff(cd.tree, cd.parent.data.tree,
-                                               quiet = True)
+                self.temp_index.apply_treediff(
+                    cd.tree, cd.parent.data.tree, quiet=True,
+                )
                 merged.append(pn)
                 # The self.temp_index was modified by apply_treediff() so
                 # force read_tree() the next time merge() is used.
                 self.temp_index_tree = None
-            except git.MergeException:
+            except MergeException:
                 pass
         if not quiet:
             out.done('%d found' % len(merged))
