@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """Basic quilt-like functionality"""
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import os
 import sys
 import traceback
@@ -33,26 +33,28 @@ along with this program; if not, see http://www.gnu.org/licenses/.
 
 class CommandAlias(object):
     def __init__(self, name, command):
-        self.__command = command
+        self._command = command
         self.__name__ = name
         self.usage = ['<arguments>']
-        self.help = 'Alias for "%s <arguments>".' % self.__command
+        self.help = 'Alias for "%s <arguments>".' % self._command
         self.options = []
 
     def func(self, args):
-        cmd = self.__command.split() + args
+        cmd = self._command.split() + args
         p = run.Run(*cmd)
         p.discard_exitcode().run()
         return p.exitcode
 
+
 def is_cmd_alias(cmd):
     return isinstance(cmd, CommandAlias)
 
+
 def append_alias_commands(cmd_list):
     for (name, command) in config.getstartswith('stgit.alias.'):
         name = utils.strip_prefix('stgit.alias.', name)
-        cmd_list[name] = (CommandAlias(name, command),
-                          'Alias commands', command)
+        cmd_list.append((name, CommandAlias(name, command), 'Alias commands', command))
+
 
 #
 # The commands map
@@ -60,6 +62,7 @@ def append_alias_commands(cmd_list):
 class Commands(dict):
     """Commands class. It performs on-demand module loading
     """
+
     def canonical_cmd(self, key):
         """Return the canonical name for a possibly-shortenned
         command name.
@@ -67,12 +70,16 @@ class Commands(dict):
         candidates = [cmd for cmd in self if cmd.startswith(key)]
 
         if not candidates:
-            out.error('Unknown command: %s' % key,
-                      'Try "%s help" for a list of supported commands' % prog)
+            out.error(
+                'Unknown command: %s' % key,
+                'Try "%s help" for a list of supported commands' % prog,
+            )
             sys.exit(utils.STGIT_GENERAL_ERROR)
         elif len(candidates) > 1:
-            out.error('Ambiguous command: %s' % key,
-                      'Candidates are: %s' % ', '.join(candidates))
+            out.error(
+                'Ambiguous command: %s' % key,
+                'Candidates are: %s' % ', '.join(candidates),
+            )
             sys.exit(utils.STGIT_GENERAL_ERROR)
 
         return candidates[0]
@@ -84,10 +91,11 @@ class Commands(dict):
         else:
             return stgit.commands.get_command(cmd_mod)
 
+
 cmd_list = stgit.commands.get_commands()
 append_alias_commands(cmd_list)
-commands = Commands((cmd, mod) for cmd, (mod, kind, help)
-                    in cmd_list.items())
+commands = Commands((cmd, mod) for cmd, mod, _, _ in cmd_list)
+
 
 def print_help():
     print('usage: %s <command> [options]' % os.path.basename(sys.argv[0]))
@@ -99,6 +107,7 @@ def print_help():
     print()
     stgit.commands.pretty_command_list(cmd_list, sys.stdout)
 
+
 #
 # The main function (command dispatcher)
 #
@@ -113,7 +122,9 @@ def _main():
 
     if len(sys.argv) < 2:
         print('usage: %s <command>' % prog, file=sys.stderr)
-        print('  Try "%s --help" for a list of supported commands' % prog, file=sys.stderr)
+        print(
+            '  Try "%s --help" for a list of supported commands' % prog, file=sys.stderr
+        )
         sys.exit(utils.STGIT_GENERAL_ERROR)
 
     cmd = sys.argv[1]
@@ -139,6 +150,7 @@ def _main():
         sys.exit(utils.STGIT_SUCCESS)
     if cmd in ['-v', '--version', 'version']:
         from stgit.version import get_version
+
         print('Stacked GIT %s' % get_version())
         os.system('git --version')
         print('Python version %s' % sys.version)
@@ -157,7 +169,6 @@ def _main():
         sys.exit(command.func(sys.argv[1:]))
 
     parser = argparse.make_option_parser(command)
-    directory = command.directory
 
     # These modules are only used from this point onwards and do not
     # need to be imported earlier
@@ -167,7 +178,7 @@ def _main():
         from ConfigParser import ParsingError, NoSectionError
     from stgit.exception import StgException
     from stgit.config import config_setup
-    from stgit.stack import Series
+    from stgit.lib.git import MergeConflictException
 
     try:
         debug_level = int(environ_get('STGIT_DEBUG_LEVEL', 0))
@@ -177,22 +188,19 @@ def _main():
 
     try:
         (options, args) = parser.parse_args()
-        directory.setup()
+        command.directory.setup()
         config_setup()
-
-        # Some commands don't (always) need an initialized series.
-        if directory.needs_current_series:
-            if hasattr(options, 'branch') and options.branch:
-                command.crt_series = Series(options.branch)
-            else:
-                command.crt_series = Series()
-
         ret = command.func(parser, options, args)
+    except MergeConflictException as err:
+        if debug_level > 1:
+            traceback.print_exc(file=sys.stderr)
+        for conflict in err.conflicts:
+            out.err(conflict)
+        sys.exit(utils.STGIT_CONFLICT)
     except (StgException, IOError, ParsingError, NoSectionError) as err:
-        directory.write_log(cmd)
         if debug_level > 0:
             traceback.print_exc(file=sys.stderr)
-        out.error(str(err), title = '%s %s' % (prog, cmd))
+        out.error(str(err), title='%s %s' % (prog, cmd))
         sys.exit(utils.STGIT_COMMAND_ERROR)
     except SystemExit:
         # Triggered by the option parser when it finds bad commandline
@@ -200,14 +208,14 @@ def _main():
         sys.exit(utils.STGIT_COMMAND_ERROR)
     except KeyboardInterrupt:
         sys.exit(utils.STGIT_GENERAL_ERROR)
-    except:
+    except BaseException:
         out.error('Unhandled exception:')
         traceback.print_exc(file=sys.stderr)
         sys.exit(utils.STGIT_BUG_ERROR)
 
-    directory.write_log(cmd)
     sys.exit(ret or utils.STGIT_SUCCESS)
 
+
 def main():
     try:
         _main()
