@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import os
 import subprocess
 import sys
@@ -9,10 +9,14 @@ from stgit.out import out
 
 
 def pager(msg):
-    if any([not hasattr(sys.stdin, 'isatty'),
+    if any(
+        [
+            not hasattr(sys.stdin, 'isatty'),
             not hasattr(sys.stdout, 'isatty'),
             not sys.stdin.isatty(),
-            not sys.stdout.isatty()]):
+            not sys.stdout.isatty(),
+        ]
+    ):
         return out.stdout_bytes(msg)
     pager = _choose_pager()
     if pager:
@@ -44,7 +48,11 @@ def _choose_pager():
             return pager
     if hasattr(os, 'system'):
         for pager in ['less', 'more']:
-            if os.system('{pager} -V >{null} 2>{null}'.format(
-                    pager=pager, null=os.devnull)) == 0:
+            if (
+                os.system(
+                    '{pager} -V >{null} 2>{null}'.format(pager=pager, null=os.devnull)
+                )
+                == 0
+            ):
                 return pager
     return None
