@@ -24,6 +24,24 @@ test_expect_success \
     [ $(stg series --applied -c) -eq 1 ]
 '
 
+test_expect_success \
+    'Invalid patch name: space' '
+    command_error stg new "bad name" 2>&1 >/dev/null |
+    grep -e "Invalid patch name: \"bad name\""
+'
+
+test_expect_success \
+    'Invalid patch name: carat' '
+    command_error stg new "bad^name" 2>&1 >/dev/null |
+    grep -e "Invalid patch name: \"bad\^name\""
+'
+
+test_expect_success \
+    'Invalid patch name: empty' '
+    command_error stg new "" 2>&1 >/dev/null |
+    grep -e "Invalid patch name: \"\""
+'
+
 test_expect_success \
     'Create a patch without giving a name' '
     stg new -m yo &&
@@ -59,7 +77,12 @@ test_expect_success \
 test_expect_success \
     'Save template' '
     stg new --save-template new-tmpl.txt &&
-    test -e new-tmpl.txt
+    test_path_is_file new-tmpl.txt
+'
+
+test_expect_failure \
+    'Patch with slash in name' '
+    stg new bar/foo -m "patch bar/foo"
 '
 
 test_done
